@@ -31,9 +31,8 @@
 namespace Poco {
 
 
-//@ deprecated
 template <class Key, class Value, class KeyHashFunction = HashFunction<Key>>
-class HashTable
+class POCO_DEPRECATED("use LinearHashTable") HashTable
 	/// A HashTable stores a key value pair that can be looked up via a hashed key.
 	///
 	/// Collision handling is done via overflow maps(!). With small hash tables performance of this
@@ -45,15 +44,15 @@ class HashTable
 	/// This class is NOT thread safe.
 {
 public:
-	typedef std::map<Key, Value> HashEntryMap;
-	typedef HashEntryMap**       HashTableVector;
+	using HashEntryMap = std::map<Key, Value>;
+	using HashTableVector = HashEntryMap **;
 
-	typedef typename HashEntryMap::const_iterator ConstIterator;
-	typedef typename HashEntryMap::iterator Iterator;
+	using ConstIterator = typename HashEntryMap::const_iterator;
+	using Iterator = typename HashEntryMap::iterator;
 
-	HashTable(UInt32 initialSize = 251): 
-		_entries(0), 
-		_size(0), 
+	HashTable(UInt32 initialSize = 251):
+		_entries(0),
+		_size(0),
 		_maxCapacity(initialSize)
 		/// Creates the HashTable.
 	{
@@ -211,21 +210,21 @@ public:
 	{
 		return get(key);
 	}
-	
+
 	Value& operator [] (const Key& key)
 	{
 		UInt32 hsh = hash(key);
 
 		if (!_entries[hsh])
 			return insertRaw(key, hsh, Value());
-			
+
 		ConstIterator it = _entries[hsh]->find(key);
 		if (it == _entries[hsh]->end())
 			return insertRaw(key, hsh, Value());
 
 		return it->second;
 	}
-	
+
 	const Key& getKeyRaw(const Key& key, UInt32 hsh)
 		/// Throws an exception if the key does not exist. returns a reference to the internally
 		/// stored key. Useful when someone does an insert and wants for performance reason only to store
@@ -276,7 +275,7 @@ public:
 	{
 		return _size;
 	}
-	
+
 	UInt32 maxCapacity() const
 	{
 		return _maxCapacity;
